@@ -1,13 +1,14 @@
-from numpy import *
-from tables import *
+import numpy as np
+import tables
 
 # Open a new empty HDF5 file
-fileh = open_file("attributes1.h5", mode = "w", title="Testing attributes")
+fileh = tables.open_file("attributes1.h5", mode="w",
+                         title="Testing attributes")
 # Get the root group
 root = fileh.root
 
 # Create an array
-a = array([1, 2, 4], int32)
+a = np.array([1, 2, 4], np.int32)
 # Save it on the HDF5 file
 hdfarray = fileh.create_array(root, 'array', a, "Integer array")
 
@@ -26,7 +27,7 @@ hdfarray.attrs.int = 12
 hdfarray.attrs.float = 12.32
 
 # A generic object
-hdfarray.attrs.object = {"a":32.1, "b":1, "c":[1, 2]}
+hdfarray.attrs.object = {"a": 32.1, "b": 1, "c": [1, 2]}
 
 # Close the file
 fileh.close()
